@@ -23,6 +23,7 @@
 #include <QCursor>
 #include <QDebug>
 #include <QRegion>
+#include <QTimer>
 
 #include <unistd.h>
 #include <string>
@@ -36,8 +37,8 @@ XWinKillPreviewWidget::XWinKillPreviewWidget(QWidget *parent) : QWidget(parent)
 {
     // new window manager instance
     m_wminfo = new WMInfo();
-// 如果在编译时选择支持 Wayland，运行时会由全局变量 WaylandCentered 控制
-// WaylandCentered 定义在 common/common.h 中，在 main 函数开头进行初始化判断
+//不再使用CMakeList开关宏的方式，改用全局变量运行时控制
+//WaylandCentered定义在common/common.h中，在main函数开头进行初始化判断
 #ifdef USE_DEEPIN_WAYLAND
     if (WaylandCentered) {
         m_connectionThread = new QThread(this);
@@ -87,15 +88,28 @@ void XWinKillPreviewWidget::mousePressEvent(QMouseEvent *event)
     auto pos = QCursor::pos();
 #ifdef USE_DEEPIN_WAYLAND
     if (WaylandCentered) {
+        double ratio = QGuiApplication::primaryScreen()->devicePixelRatio(); // 获得当前的缩放比例
+        QRect screenRect;
+        for (auto screen : QApplication::screens()) {
+            // screen geometry
+            auto geom = screen->geometry();
+            if (geom.contains(pos)) {
+                screenRect = geom;
+                break;
+            }
+        }
         for (QVector<ClientManagement::WindowState>::iterator it = m_windowStates.end() - 1;
                 it != m_windowStates.begin(); --it) {
             // if the window is created by ourself, then ignore it
-            if (getpid() == it->pid || QString::fromStdString(it->resourceName) == "dde-desktop" || it->isMinimized)
+            if (getpid() == it->pid || QString::fromStdString(it->resourceName) == "dde-desktop" || it->isMinimized
+                    || QString::fromStdString(it->resourceName) == "deepin-deepinid-client"
+                    || QString::fromStdString(it->resourceName) == "dde-dock")
                 continue;
 
             // if such window exists, we emit window clicked signal to notify kill application performed action
-            QRect rect;
-            rect.setRect(it->geometry.x, it->geometry.y, it->geometry.width, it->geometry.height);
+            QRect rect(static_cast<int>(screenRect.x() + (it->geometry.x - screenRect.x()) / ratio),
+                       static_cast<int>(screenRect.y() + (it->geometry.y - screenRect.y()) / ratio),
+                       static_cast<int>(it->geometry.width / ratio), static_cast<int>(it->geometry.height / ratio));
             if (rect.contains(pos)) {
                 // hide preview & background widgets first
                 hide();
@@ -112,11 +126,24 @@ void XWinKillPreviewWidget::mousePressEvent(QMouseEvent *event)
         }
     }
 #endif // USE_DEEPIN_WAYLAND
+
     if (!WaylandCentered) {
-        auto list = m_wminfo->selectWindow(pos);
+        double ratio = QGuiApplication::primaryScreen()->devicePixelRatio(); // 获得当前的缩放比例
+        QRect screenRect;
+        for (auto screen : QApplication::screens()) {
+            // screen geometry
+            auto geom = screen->geometry();
+            if (geom.contains(pos)) {
+                screenRect = geom;
+                break;
+            }
+        }
+        QPoint windowPos(static_cast<int>(screenRect.x() + (pos.x() - screenRect.x())*ratio),
+                         static_cast<int>(screenRect.y() + (pos.y() - screenRect.y())*ratio));
+        auto list = m_wminfo->selectWindow(windowPos);
 
         // fix cursor not update issue while moved to areas covered by intersected area of dock & normal windows
-        if (m_wminfo->isCursorHoveringDocks(pos)) {
+        if (m_wminfo->isCursorHoveringDocks(windowPos)) {
             return;
         }
 
@@ -126,7 +153,7 @@ void XWinKillPreviewWidget::mousePressEvent(QMouseEvent *event)
                 continue;
 
             // if such window exists, we emit window clicked signal to notify kill application performed action
-            if (select->rect.contains(pos)) {
+            if (select->rect.contains(windowPos)) {
                 // hide preview & background widgets first
                 hide();
                 for (auto &background : m_backgroundList) {
@@ -148,8 +175,17 @@ void XWinKillPreviewWidget::mouseMoveEvent(QMouseEvent *)
 {
 #ifdef USE_DEEPIN_WAYLAND
     if (WaylandCentered) {
-        double x = QGuiApplication::primaryScreen()->devicePixelRatio(); // 获得当前的缩放比例
+        double ratio = QGuiApplication::primaryScreen()->devicePixelRatio(); // 获得当前的缩放比例
         auto pos = QCursor::pos();
+        QRect screenRect;
+        for (auto screen : QApplication::screens()) {
+            // screen geometry
+            auto geom = screen->geometry();
+            if (geom.contains(pos)) {
+                screenRect = geom;
+                break;
+            }
+        }
         // get the list of windows under cursor from cache in stacked order
         bool found {false};
 
@@ -157,11 +193,13 @@ void XWinKillPreviewWidget::mouseMoveEvent(QMouseEvent *)
                 it != m_windowStates.begin(); --it) {
             // if the window is created by ourself, then ignore it
             // wayland环境下增加桌面窗口和dock栏的屏蔽
-            if (getpid() == it->pid || QString::fromStdString(it->resourceName) == "dde-desktop" || it->isMinimized || QString::fromStdString(it->resourceName) == "deepin-deepinid-client"
+            if (getpid() == it->pid || QString::fromStdString(it->resourceName) == "dde-desktop" || it->isMinimized
+                    || QString::fromStdString(it->resourceName) == "deepin-deepinid-client"
                     || QString::fromStdString(it->resourceName) == "dde-dock")
                 continue;
-            auto selRect = QRect(static_cast<int>(it->geometry.x / x), static_cast<int>(it ->geometry.y / x),
-                                 static_cast<int>(it->geometry.width / x), static_cast<int>(it->geometry.height / x));
+            auto selRect = QRect(static_cast<int>(screenRect.x() + (it->geometry.x - screenRect.x()) / ratio),
+                                 static_cast<int>(screenRect.y() + (it->geometry.y - screenRect.y()) / ratio),
+                                 static_cast<int>(it->geometry.width / ratio), static_cast<int>(it->geometry.height / ratio));
             if (selRect.contains(pos)) {
                 found = true;
 
@@ -177,8 +215,9 @@ void XWinKillPreviewWidget::mouseMoveEvent(QMouseEvent *)
 
                     else {
                         //上方的堆叠窗口区域
-                        auto upRegion = QRect(static_cast<int>(iter->geometry.x / x), static_cast<int>(iter ->geometry.y / x),
-                                              static_cast<int>(iter->geometry.width / x), static_cast<int>(iter->geometry.height / x));
+                        auto upRegion = QRect(static_cast<int>(screenRect.x() + (iter->geometry.x - screenRect.x()) / ratio),
+                                              static_cast<int>(screenRect.y() + (iter->geometry.y - screenRect.y()) / ratio),
+                                              static_cast<int>(iter->geometry.width / ratio), static_cast<int>(iter->geometry.height / ratio));
 
                         region = region.subtracted(upRegion);
                     }
@@ -209,33 +248,47 @@ void XWinKillPreviewWidget::mouseMoveEvent(QMouseEvent *)
     }
 #endif // USE_DEEPIN_WAYLAND
     if (!WaylandCentered) {
-        double x = QGuiApplication::primaryScreen()->devicePixelRatio(); // 获得当前的缩放比例
+        double ratio = QGuiApplication::primaryScreen()->devicePixelRatio(); // 获得当前的缩放比例
         auto pos = QCursor::pos();
+        QRect screenRect;
+        for (auto screen : QApplication::screens()) {
+            // screen geometry
+            auto geom = screen->geometry();
+            if (geom.contains(pos)) {
+                screenRect = geom;
+                break;
+            }
+        }
+        QPoint windowPos(static_cast<int>(screenRect.x() + (pos.x() - screenRect.x())*ratio),
+                         static_cast<int>(screenRect.y() + (pos.y() - screenRect.y())*ratio));
         // get the list of windows under cursor from cache in stacked order
-        auto list = m_wminfo->selectWindow(pos);
+        auto list = m_wminfo->selectWindow(windowPos);
         bool found {false};
 
         // fix cursor not update issue while moved to areas covered by intersected area of dock & normal windows
-        if (m_wminfo->isCursorHoveringDocks(pos)) {
+        if (m_wminfo->isCursorHoveringDocks(windowPos)) {
             for (auto &bg : m_backgroundList)
                 bg->clearSelection();
             emit cursorUpdated(m_defaultCursor);
             return;
         }
-
         for (auto &select : list) {
             // if the window is created by ourself, then ignore it
             if (getpid() == select->pid)
                 continue;
-            auto selRect = QRect(static_cast<int>(select->rect.x() / x), static_cast<int>(select->rect.y() / x), static_cast<int>(select->rect.width() / x), static_cast<int>(select->rect.height() / x));
+            QRect selRect(static_cast<int>(screenRect.x() + (select->rect.x() - screenRect.x()) / ratio),
+                          static_cast<int>(screenRect.y() + (select->rect.y() - screenRect.y()) / ratio),
+                          static_cast<int>(select->rect.width() / ratio), static_cast<int>(select->rect.height() / ratio));
             if (selRect.contains(pos)) {
                 found = true;
 
                 // find all windows hovered above, if any clip out the intersected region
-                auto hoveredBy = m_wminfo->getHoveredByWindowList(select->wid, selRect);
+                auto hoveredBy = m_wminfo->getHoveredByWindowList(select->wid, select->rect);
                 QRegion region {selRect};
                 for (auto &hover : hoveredBy) {
-                    auto hoverrect = QRect(static_cast<int>(hover->rect.x() / x), static_cast<int>(hover->rect.y() / x), static_cast<int>(hover->rect.width() / x), static_cast<int>(hover->rect.height() / x));
+                    QRect hoverrect(static_cast<int>(screenRect.x() + (hover->rect.x() - screenRect.x()) / ratio),
+                                    static_cast<int>(screenRect.y() + (hover->rect.y() - screenRect.y()) / ratio),
+                                    static_cast<int>(hover->rect.width() / ratio), static_cast<int>(hover->rect.height() / ratio));
                     region = region.subtracted(hoverrect);
                 }
 
@@ -274,7 +327,7 @@ void XWinKillPreviewWidget::keyPressEvent(QKeyEvent *event)
         close();
     }
 }
-#include <QTimer>
+
 // initialize ui components
 void XWinKillPreviewWidget::initUI()
 {
@@ -307,12 +360,12 @@ void XWinKillPreviewWidget::initUI()
             // screen geometry
             auto geom = screen->geometry();
             // snapshot current scree
-            auto pixmap = screen->grabWindow(m_wminfo->getRootWindow(), geom.x(), geom.y(), geom.width(), geom.height());
+            auto pixmap = screen->grabWindow(m_wminfo->getRootWindow());
 #ifdef USE_DEEPIN_WAYLAND
             if (WaylandCentered)
-                pixmap = screen->grabWindow(m_windowStates.end()->windowId,
-                                            geom.x(), geom.y(), geom.width(), geom.height());
+                pixmap = screen->grabWindow(m_windowStates.end()->windowId);
 #endif // USE_DEEPIN_WAYLAND
+            pixmap = pixmap.copy(geom.x(), geom.y(), static_cast<int>(geom.width() * devicePixelRatioF()), static_cast<int>(geom.height() * devicePixelRatioF()));
             // create preview background widget for each screen
             auto *background = new XWinKillPreviewBackgroundWidget(pixmap, this);
             // update cursor on cursor updated signal
@@ -355,9 +408,8 @@ void XWinKillPreviewWidget::initConnections()
     }
 #endif // USE_DEEPIN_WAYLAND
 }
-
-#ifdef USE_DEEPIN_WAYLAND
 //打印当前窗口信息接口
+#ifdef USE_DEEPIN_WAYLAND
 void XWinKillPreviewWidget::print_window_states(const QVector<ClientManagement::WindowState> &m_windowStates)
 {
     if (WaylandCentered) {
@@ -374,7 +426,11 @@ void XWinKillPreviewWidget::print_window_states(const QVector<ClientManagement::
         }
     }
 }
+#endif // USE_DEEPIN_WAYLAND
+
+
 //wayland 注册
+#ifdef USE_DEEPIN_WAYLAND
 void XWinKillPreviewWidget::setupRegistry(Registry *registry)
 {
     if (WaylandCentered) {
@@ -407,6 +463,6 @@ void XWinKillPreviewWidget::setupRegistry(Registry *registry)
         registry->create(m_connectionThreadObject);
         registry->setup();
     }
-
 }
-#endif //WAYLAND_SESSION_SUPPORT
+#endif // USE_DEEPIN_WAYLAND
+
