@@ -772,6 +772,13 @@ RX</translation>
         <translation>Semua proses</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -1103,4 +1110,4 @@ RX</translation>
         <translation>Perkhidmatan</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
