@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
 <context>
     <name>App.About</name>
     <message>
@@ -505,13 +505,6 @@ Weet je zeker dat je door wilt gaan?</translation>
         <translation>Beëindigen</translation>
     </message>
 </context>
-<context>
-    <name>MainWindow</name>
-    <message>
-        <source>Settings</source>
-        <translation>Instellingen</translation>
-    </message>
-</context>
 <context>
     <name>MemStatViewWidget</name>
     <message>
@@ -771,6 +764,13 @@ Weet je zeker dat je door wilt gaan?</translation>
         <translation>Alle processen</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Bezig met laden…</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -977,10 +977,12 @@ Weet je zeker dat je door wilt gaan?</translation>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>Oké</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>Annuleren</translation>
     </message>
 </context>
@@ -1102,4 +1104,4 @@ Weet je zeker dat je door wilt gaan?</translation>
         <translation>Diensten</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
