@@ -98,7 +98,7 @@
     </message>
     <message>
         <source>Load average</source>
-        <translation>負載均衡</translation>
+        <translation>平均負載</translation>
     </message>
     <message>
         <source>File descriptors</source>
@@ -771,6 +771,13 @@ Are you sure you want to continue?</source>
         <translation>所有進程</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>正在加載</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -977,10 +984,12 @@ Are you sure you want to continue?</source>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>確 定</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>取 消</translation>
     </message>
 </context>
@@ -1102,4 +1111,4 @@ Are you sure you want to continue?</source>
         <translation>系統服務</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
